# ----------------------------------------------------------------------------
# Copyright (C) 2021 Deepchecks (https://www.deepchecks.com)
#
# This file is part of Deepchecks.
# Deepchecks is distributed under the terms of the GNU Affero General
# Public License (version 3 or later).
# You should have received a copy of the GNU Affero General Public License
# along with Deepchecks.  If not, see <http://www.gnu.org/licenses/>.
# ----------------------------------------------------------------------------
#
"""Top module for deepchecks library."""
import matplotlib
import plotly.io as pio
from pkg_resources import get_distribution, DistributionNotFound
from .utils.ipython import is_notebook
from .base import (
    Dataset,
    BaseCheck,
    SingleDatasetBaseCheck,
    TrainTestBaseCheck,
    ModelOnlyBaseCheck,
    ModelComparisonBaseCheck,
    CheckResult,
    CheckFailure,
    Condition,
    ConditionResult,
    ConditionCategory,
    BaseSuite,
    Suite,
    SuiteResult,
    ModelComparisonSuite,
    CheckRunContext
)

__all__ = [
    'Dataset',
    'BaseCheck',
    'SingleDatasetBaseCheck',
    'TrainTestBaseCheck',
    'ModelOnlyBaseCheck',
    'ModelComparisonBaseCheck',
    'CheckResult',
    'CheckFailure',
    'Condition',
    'ConditionResult',
    'ConditionCategory',
    'BaseSuite',
    'Suite',
    'SuiteResult',
    'ModelComparisonSuite',
    'CheckRunContext'
]

# Matplotlib has multiple backends. If we are in a context that does not support GUI (For example, during unit tests)
# we can't use a GUI backend. Thus we must use a non-GUI backend.
if not is_notebook():
    matplotlib.use('Agg')

# We can't rely on that the user will have an active internet connection, thus we change the default backend to
# "notebook" If plotly detects the 'notebook-connected' backend.
# for more info, see: https://plotly.com/python/renderers/
pio_backends = pio.renderers.default.split('+')
if 'notebook_connected' in pio_backends:
    pio_backends[pio_backends.index('notebook_connected')] = 'notebook'
    pio.renderers.default = '+'.join(pio_backends)


# Set version info
try:
    __version__ = get_distribution('deepchecks').version
except Exception: # pylint: disable=broad-except
    # If distribution can't be found, leave version empty
    __version__ = ''
